@@ -126,6 +126,9 @@ var (
 		group{name: "sma", prefixes: []string{
 			"sma.",
 		}},
+		group{name: "smf", prefixes: []string{
+			"smf.",
+		}},
 		group{name: "mgt", prefixes: []string{
 			"mgt.",
 		}},
@@ -162,13 +165,6 @@ var (
 			total:     "main_n_wrk",
 			desc:      "Number of worker threads",
 		},
-		&grouping{
-			newPrefix: "main_bans",
-			prefix:    "main_n_ban",
-			total:     "main_n_ban",
-			desc:      "Number of bans",
-			labelKey:  "action",
-		},
 	}
 	fqNames = map[string]string{
 		"varnish_lck_colls":   "varnish_lock_collisions",
@@ -188,6 +184,16 @@ var (
 		"varnish_sma_g_alloc":     "type",
 		"varnish_sma_g_bytes":     "type",
 		"varnish_sma_g_space":     "type",
+		"varnish_smf_c_bytes":     "type",
+		"varnish_smf_c_fail":      "type",
+		"varnish_smf_c_freed":     "type",
+		"varnish_smf_c_req":       "type",
+		"varnish_smf_g_alloc":     "type",
+		"varnish_smf_g_bytes":     "type",
+		"varnish_smf_g_smf_frag":  "type",
+		"varnish_smf_g_smf_large": "type",
+		"varnish_smf_g_smf":       "type",
+		"varnish_smf_g_space":     "type",
 	}
 )
 
@@ -217,6 +223,16 @@ func cleanBackendName(name string) string {
 			name = name[len(prefix):]
 		}
 	}
+
+	// reload_2019-08-29T100458.<name> as by varnish_reload_vcl in 4.x
+	// reload_20191014_091124_78599.<name> as by varnishreload in 6+
+	if strings.HasPrefix(name, "reload_") {
+		dot := strings.Index(name, ".")
+		if dot != -1 {
+			name = name[dot + 1:]
+		}
+	}
+
 	return name
 }
 
